==> responsive_favicons-2.0.0.tar.gz: responsive_favicons/src/Routing/DefaultFavicons.php <==
<?php

/**
 * @file
 * Contains \Drupal\responsive_favicons\Routing\DefaultFavicons.
 */

namespace Drupal\responsive_favicons\Routing;

use Drupal\Core\Routing\RouteSubscriberBase;
use Symfony\Component\Routing\RouteCollection;
use Symfony\Component\Routing\Route;

/**
 * Class DefaultFavicons.
 *
 * @package Drupal\responsive_favicons\Routing
 * Listens to the dynamic route events.
 */
class DefaultFavicons {

  /**
   * {@inheritdoc}
   */
  public function routes() {
    $route_collection = new RouteCollection();
    $moduleHandler = \Drupal::service('module_handler');

    // List of icons to redirect.
    // Note, in order for these to work alter the fast404 pattern to allow these
    // requests to hit Drupal. Please see the README for more information.
    $icons = [
      '/apple-touch-icon.png',
      '/apple-touch-icon-precomposed.png',
      '/browserconfig.xml',
    ];
    // Try to avoid clashing with the favicon module.
    if (!$moduleHandler->moduleExists('favicon')) {
      $icons[] = '/favicon.ico';
    }
    foreach($icons as $icon) {
      $route = new Route(
        // Path to attach this route to:
        $icon,
        // Route defaults:
        [
          '_controller' => '\Drupal\responsive_favicons\Controller\GetFile::deliver',
          '_title' => ''
        ],
        // Route requirements:
        [
          '_access' => 'TRUE',
        ]
      );
      // Add the route under a unique key.
      $key = preg_replace("/[^A-Za-z]/", '', $icon);
      $route_collection->add('responsive_favicons.' . $key, $route);
    }

    return $route_collection;
  }
}

==> responsive_favicons-3.0.0-rc1.tar.gz: responsive_favicons/src/Routing/DefaultFavicons.php <==
<?php

namespace Drupal\responsive_favicons\Routing;

use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Extension\ModuleHandler;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\Routing\RouteCollection;
use Symfony\Component\Routing\Route;

/**
 * The DefaultFavicons route callback handler.
 *
 * @package Drupal\responsive_favicons\Routing
 * Listens to the dynamic route events.
 */
class DefaultFavicons implements ContainerInjectionInterface {

  public function __construct(protected ModuleHandler $moduleHandler) {}

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    // @phpstan-ignore-next-line
    return new static(
      $container->get('module_handler'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function routes() {
    $route_collection = new RouteCollection();

    // List of icons to redirect.
    // Note, in order for these to work alter the fast404 pattern to allow these
    // requests to hit Drupal. Please see the README for more information.
    $icons = [
      '/apple-touch-icon.png',
      '/apple-touch-icon-precomposed.png',
      '/browserconfig.xml',
      '/site.webmanifest',
      '/favicon.svg',
    ];
    // Try to avoid clashing with the favicon module.
    if (!$this->moduleHandler->moduleExists('favicon')) {
      $icons[] = '/favicon.ico';
    }
    foreach ($icons as $icon) {
      $route = new Route(
        // Path to attach this route to:
        $icon,
        // Route defaults:
        [
          '_controller' => '\Drupal\responsive_favicons\Controller\GetFile::deliver',
          '_title' => '',
        ],
        // Route requirements:
        [
          '_access' => 'TRUE',
        ]
      );
      // Add the route under a unique key.
      $key = preg_replace("/[^A-Za-z]/", '', $icon);
      $route_collection->add('responsive_favicons.' . $key, $route);
    }

    return $route_collection;
  }

}
